@@ -25,9 +25,23 @@ sub extract {
 sub source {
     my $class = ref $_[0] || $_[0];
     no strict 'refs';
-    return ref ${"$class\::Remote"}{source} && wantarray
-           ? @{${"$class\::Remote"}{source}}
-           :   ${"$class\::Remote"}{source};
+
+    return ${"$class\::Remote"}{source};
+}
+
+sub sources {
+    my $class = ref $_[0] || $_[0];
+    no strict 'refs';
+
+    my $src = ${"$class\::Remote"}{source};
+    if ( ref $src eq 'ARRAY' ) {
+        return @$src;
+    }
+    elsif ( ref $src eq 'HASH' ) {
+        return
+            map { ref $_ ? @$_ : $_ } $_[1] ? $src->{ $_[1] } : values %$src;
+    }
+    return $src;
 }
 
 sub has_remotelist { return defined $_[0]->source(); }
@@ -46,7 +60,7 @@ sub remote_list {
 
     # fetch the content
     my @items;
-    my @srcs = $class->source();                                               
+    my @srcs = $class->sources($_[1]);
     my $ua   = LWP::UserAgent->new( env_proxy => 1 );
     foreach my $src (@srcs) {
         my $res  = $ua->request( HTTP::Request->new( GET => $src ) );
@@ -59,7 +73,9 @@ sub remote_list {
         push @items => $class->extract( $res->content() );
     }
 
-    return @items;
+    # return unique items
+    my %seen;
+    return grep { !$seen{$_}++ } @items;
 }
 
 #
@@ -78,6 +94,28 @@ sub tr_accent {
     return $str;
 }
 
+my %utf2asc = (
+    "\xc3\x89" => 'E',
+    "\xc3\xa0" => 'a',
+    "\xc3\xa1" => 'a',
+    "\xc3\xa9" => 'e',
+    "\xc3\xaf" => 'i',
+    "\xc3\xad" => 'i',
+    "\xc3\xb6" => 'o',
+    "\xc3\xb8" => 'o',
+    "\xc5\xa0" => 'S',
+    # for pokemons
+    "\xe2\x99\x80" => 'female',
+    "\xe2\x99\x82" => 'male',
+);
+my $utf_re = qr/(@{[join( '|', sort keys %utf2asc )]})/; 
+
+sub tr_utf8_basic {
+    my $str = shift;
+    $str =~ s/$utf_re/$utf2asc{$1}/go;
+    return $str;
+}
+
 1;
 
 __END__
@@ -164,7 +202,17 @@ if the theme actually has a remote list).
 
 =item source()
 
-Return the source URL.
+Return the data structure containing the source URLs. This can be quite
+different depending on the class: a single scalar (URL), an array
+reference (list of URLs) or a hash reference (each value being either
+a scalar or an array reference) for themes that are subclasses of
+C<Acme::MetaSyntactic::MultiList>.
+
+=item sources( [ $category ] )
+
+Return the list of source URL. The C<$category> parameter can be used
+to select the sources for a sub-category of the theme (in the case of
+C<Acme::MetaSyntactic::MultiList>).
 
 =item extract( $content )
 
@@ -190,6 +238,12 @@ underscores (C<_>).
 Return a copy of C<$str> will all iso-8859-1 accented characters turned
 into basic ASCII characters.
 
+=item tr_utf8_basic( $str )
+
+Return a copy of C<$str> with some of the utf-8 accented characters turned
+into basic ASCII characters. This is very crude, but I didn't to bother
+and depend on the proper module to do that.
+
 =back
 
 =head1 AUTHOR
@@ -214,7 +268,7 @@ L<Acme::MetaSyntactic::Locale>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Philippe 'BooK' Bruhat, All Rights Reserved.
+Copyright 2005-2006 Philippe 'BooK' Bruhat, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
